@@ -5,23 +5,17 @@ import matplotlib.pyplot as plt
 from pyvis.physics import Physics
 from pyvis.network import Network
 import time,re,spacy,itertools
-from keypartx.basemodes.text_edges import text2edges
+from keypartx.basemodes.text_edges import text2edges, opi_verbs,neg_words,nounDEL,adjDEL
 import pandas as pd 
 import math, matplotlib
 from itertools import cycle, islice
-import coreferee
-
-
-nlp = spacy.load('en_core_web_lg')
-try:
-  nlp.add_pipe('coreferee')
-except:
-  print('Coreference is not available!!!')
+from keypartx.basemodes.avn_base import coreNLP
 
+nlp = coreNLP()
 
 
 ## -- avnn edges-- ##
-def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,only_otherNouns = False, only_opiAV = True, nncompound = True):
+def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,only_otherNouns = False, only_opiAV = True, nncompound = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL):
 
     time_start = time.time()
     all_adjV2N_edges = []
@@ -56,7 +50,7 @@ def avnn(comments_en,by_review = False,other_edges = True,verbose_text = False,o
             line1 = re.sub(' +', ' ', line1).strip() #remove extra space whitespace 
             print('line1:', line1)
             if by_review:
-                all_adjV2N_edges0, allNNedges0, all_new_nodes0, all_old_nodes0,new_node_nouns0,new_node_verbs0,new_node_adjs0 = text2edges(line1,verbose= False, verbose_text = verbose_text,include_otherEdge = other_edges,only_otherNouns =only_otherNouns,only_opiAV = only_opiAV,nncompound= nncompound)
+                all_adjV2N_edges0, allNNedges0, all_new_nodes0, all_old_nodes0,new_node_nouns0,new_node_verbs0,new_node_adjs0 = text2edges(line1,verbose= False, verbose_text = verbose_text,include_otherEdge = other_edges,only_otherNouns =only_otherNouns,only_opiAV = only_opiAV,nncompound= nncompound, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL)
                 #all_adjV2N_edges, allNNedges, all_adjV2N_edges_drop, all_new_nodes, all_old_nodes,new_node_nouns,new_node_verbs,new_node_adjs
                 allNNedges.extend(allNNedges0)
                 all_adjV2N_edges.extend(all_adjV2N_edges0)
