@@ -1,9 +1,8 @@
 
 import pandas as pd
 import re 
-import coreferee, spacy
-from spacy import displacy
-
+#import coreferee, spacy
+#from spacy import displacy
 
 from autocorrect import Speller
 import re
@@ -12,7 +11,7 @@ from collections import defaultdict
 
 import matplotlib.pylab as plt
 import networkx as nx
-from matplotlib.pyplot import figure, text
+#from matplotlib.pyplot import figure, text
 
 
 ## negative, conative verbs, non opinion adjective, arcticle, ordinal words
@@ -54,12 +53,6 @@ def negADJ(neg_words,adjDEL):
 
 
 
-nlp = spacy.load('en_core_web_lg')
-try:
-  nlp.add_pipe('coreferee')
-except:
-  print('Coreference is not available!!!')
-
 
 def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,only_opiAV = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,nncompound = False,):
   """
